@@ -3,7 +3,7 @@
 # vim: se ts=4 et syn=python:
 
 # created by: matteo.guadrini
-# __init__.py -- pyreports
+# __init__ -- pyreports
 #
 #     Copyright (C) 2022 Matteo Guadrini <matteo.guadrini@hotmail.it>
 #
@@ -26,4 +26,4 @@ from .io import manager
 from .core import Executor, Report, ReportBook
 from .exception import ReportDataError, ReportManagerError
 from .datatools import average, most_common, percentage, counter, aggregate, chunks, merge
-
+from .cli import make_manager, get_data, load_config, validate_config
