@@ -23,9 +23,10 @@
 """Contains all business logic and data processing."""
 
 # region Imports
+import os
+import ssl
 import tablib
 import smtplib
-import ssl
 from email.mime.text import MIMEText
 from email.mime.multipart import MIMEMultipart
 from email import encoders
@@ -76,6 +77,32 @@ class Executor:
         """
         return str(self.data)
 
+    def __getitem__(self, item):
+        """Get row into Dataset object
+
+        :param item: row (int)
+        :return: row
+        """
+        return self.data[item]
+
+    def __delitem__(self, key):
+        """Delete row into Dataset object
+
+        :param key: row (int)
+        :return: None
+        """
+        del self.data[key]
+
+    def __contains__(self, item):
+        """Check if item is in Dataset Executor object
+
+        :param item: Any item
+        :return: bool
+        """
+        for row in self.data:
+            if item in row:
+                return True
+
     def get_data(self):
         """Get dataset
 
@@ -253,13 +280,44 @@ class Report:
         """
         return str(self._print_data())
 
+    def __bool__(self):
+        """Boolean value
+
+        :return: bool
+        """
+        return True if self.report else False
+
+    def __iter__(self):
+        """Return report iterator
+
+        :return: iterable object
+        """
+        return (row for row in self.report)
+
+    def __getitem__(self, item):
+        """Get row of report
+
+        :param item: int row index
+        :return: row tuple
+        """
+        return self.report[item]
+
+    def __delitem__(self, key):
+        """Delete row of report
+
+        :param key: int row index
+        :return: None
+        """
+        if self.report:
+            del self.report[key]
+
     def _print_data(self):
         """Print data and count
 
         :return: data and count
         """
-        if isinstance(self.report, tuple):
-            out = f'{self.report[0]}\nrows: {self.report[1]}'
+        if self.count:
+            out = f'{self.report}\nrows: {int(self.count)}'
             return out
         else:
             return self.report
@@ -329,7 +387,13 @@ class Report:
         if bcc:
             message["Bcc"] = bcc
         if headers:
-            message.add_header(*headers)
+            if all([isinstance(header, (tuple, list)) for header in headers]):
+                for header in headers:
+                    message.add_header(*header)
+            elif isinstance(headers, (tuple, list)):
+                message.add_header(*headers)
+            else:
+                raise ValueError(f'headers must be tuple or List[tuple]')
 
         # Prepare body
         part = MIMEText(body, "html")
@@ -342,7 +406,7 @@ class Report:
         payload = MIMEBase('application', 'octate-stream')
         payload.set_payload(attach_file.read())
         encoders.encode_base64(payload)
-        payload.add_header('Content-Disposition', 'attachment', filename=attach_file_name)
+        payload.add_header('Content-Disposition', 'attachment', filename=os.path.basename(attach_file_name))
         message.attach(payload)
 
         # Prepare SMTP connection
@@ -419,6 +483,30 @@ class ReportBook:
         """
         return f"<ReportBook object, title={self.title if self.title else None}>"
 
+    def __bool__(self):
+        """Boolean value
+
+        :return: bool
+        """
+        return True if self.reports else False
+
+    def __getitem__(self, item):
+        """Get Report objects
+
+        :param item: Report int index
+        :return: Report
+        """
+        return self.reports[item]
+
+    def __delitem__(self, key):
+        """Delete Report object
+
+        :param key: Report int index
+        :return: None
+        """
+        if self.reports:
+            del self.reports[key]
+
     def add(self, report: Report):
         """Add report object
 
